`teaching.bb-ai.net/KRR/Prover9`

## KRR Assignment 1 (Autumn 2020)

The aim of this assignment is to encode reasoning problems stated in English into classical logic. Prover9 should used to edit and test the representations. The required submission consists of Prover9 input files that are to be submitted to Gradescope.

- There are two problems, one should be encoded in propositional logic and the other requires first-order-logic (with equality). Links to the problems are below.

- More information on using Prover9 can be found on my Prover9 exercises information web page.

### The Problems:

1. The Commuter (18 marks)
2. The Missing Reflection (42 marks)

Total marks available: 60

Gradescope
If you are taking one of Brandon's KRR modules, your solutions can be checked and marked automatically using software that has been implemented by embedding Prover9 within the Gradescope platform. Follow the link to Gradescope on the 'Submit My Work' page of the module's Minerva web pages, and look for the assignment: Assignment 1